@@ -6,8 +6,8 @@
 ;; Keywords: extensions, tools
 ;; URL: https://github.com/kaiwk/leetcode.el
 ;; Package-Requires: ((emacs "28.1") (s "1.13.0") (aio "1.0") (log4e "0.3.3"))
-;; Package-Version: 0.1.28
-;; Package-Revision: 02eb6ff9c75b
+;; Package-Version: 20250417.1453
+;; Package-Revision: 7f1d6804ed3b
 
 ;; This program is free software; you can redistribute it and/or modify
 ;; it under the terms of the GNU General Public License as published by
@@ -1081,6 +1081,8 @@ STATUS_CODE has following possible value:
 
 - 10: Accepted
 - 11: Wrong Anwser
+- 12: Memory Limit Exceeded
+- 13: Output Limit Exceeded
 - 14: Time Limit Exceeded
 - 15: Runtime Error.  full_runtime_error
 - 20: Compile Error.  full_compile_error"
@@ -1108,6 +1110,12 @@ STATUS_CODE has following possible value:
         (insert (format "Expected Answer: %s\n\n" .expected_output))
         (unless (string-empty-p .std_output)
           (insert (format "Stdout: \n%s\n" .std_output))))
+       ((eq .status_code 12)
+        (insert (format "Status: %s" (leetcode--add-font-lock .status_msg 'leetcode-error-face)))
+        (insert (format "\n\n%s / %s testcases passed\n" .total_correct .total_testcases))
+        (insert (format "Last Test Case: %s\n" .last_testcase)))
+       ((eq .status_code 13)
+        (insert (format "Status: %s" (leetcode--add-font-lock .status_msg 'leetcode-error-face))))
        ((eq .status_code 14)
         (insert (format "Status: %s" (leetcode--add-font-lock .status_msg 'leetcode-error-face)))
         (insert (format "\n\n%s / %s testcases passed\n" .total_correct .total_testcases))
